@@ -47,12 +47,7 @@ class TreeExtractor(object):
         css rules matching the cleaned html tree
         """
         # Clean HTML
-        cleaned_tree = self._extract_html(html_contents)
-
-        if cleaned_tree is not None:
-            cleaned_html = html.tostring(cleaned_tree).decode()
-        else:
-            cleaned_html = None
+        cleaned_html = self._extract_html(html_contents)
 
         # Clean CSS
         if css_contents is not None:
@@ -81,7 +76,7 @@ class TreeExtractor(object):
         self.elts_to_remove = []
 
         # Check if the root is a match or if there is any matches
-        is_root = self.tree in self.elts_to_keep
+        is_root = self._is_keep(self.tree)
         has_descendant = self._has_keep_elt_in_descendants(self.tree)
 
         if not(is_root or has_descendant):
@@ -91,7 +86,7 @@ class TreeExtractor(object):
         self._parse_element(self.tree, is_keep=is_root)
         self._remove_elements()
 
-        return self.tree
+        return html.tostring(self.tree).decode()
 
     def _get_elements_to_keep(self):
         """
@@ -112,14 +107,14 @@ class TreeExtractor(object):
         for e in elt.iterchildren():
 
             # Element is an explicit one to discard, flag it and continue
-            if e in self.elts_to_discard:
+            if self._is_discard(e):
                 self.elts_to_remove.append(e)
                 continue
 
             if not is_keep:
                 # Parent element is not an explicit keep, normal process
                 # Element is an explicit one to keep, inspect it
-                if e in self.elts_to_keep:
+                if self._is_keep(e):
                     self._parse_element(e, is_keep=True)
                     continue
 
@@ -135,6 +130,18 @@ class TreeExtractor(object):
                 # Element is a child of a keep element, only check explicit discards
                 self._parse_element(e, is_keep=True)
 
+    def _is_keep(self, elt):
+        """
+        Returns whether an Element is an explicit one to keep or not
+        """
+        return elt in self.elts_to_keep
+
+    def _is_discard(self, elt):
+        """
+        Returns whether an Element is an explicit one to discard or not
+        """
+        return elt in self.elts_to_discard
+
     def _has_keep_elt_in_descendants(self, elt):
         """
         Returns whether the element has a descendant to keep or not
@@ -183,7 +190,6 @@ class TreeExtractor(object):
         # Init the cleaned CSS rules and contents string
         css_rules = []
 
-
         # For every rule in the CSS
         for rule in stylesheet.rules:
             try:
@@ -201,8 +207,8 @@ class TreeExtractor(object):
         """
         Returns whether the rule matches the HTML tree
         """
-        return any(self.tree.xpath(self.xpath_translator.selector_to_xpath(selector))\
-            for selector in cssselect.parse(rule.selector.as_css()))
+        return any(self.tree.xpath(self.xpath_translator.selector_to_xpath(selector))
+                   for selector in cssselect.parse(rule.selector.as_css()))
 
     def _build_css(self, rules):
         """
